==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardParametersDateTimeParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardParametersDateTimeParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Display name for the dashboard.
 * @property values
 */
public data class DashboardParametersDateTimeParameterArgs(
    public val name: Output<String>,
    public val values: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardParametersDateTimeParameterArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardParametersDateTimeParameterArgs =
        com.pulumi.aws.quicksight.inputs.DashboardParametersDateTimeParameterArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DashboardParametersDateTimeParameterArgs].
 */
@PulumiTagMarker
public class DashboardParametersDateTimeParameterArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var values: Output<List<String>>? = null

    /**
     * @param value Display name for the dashboard.
     */
    @JvmName("fybtvbakmkvwejgq")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("lptptbetsjfytodk")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("piuwkequoxlhphsm")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("nelgllcvsixylmhq")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Display name for the dashboard.
     */
    @JvmName("paxcujevyiorewty")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("hkqpjbnfstabyqmn")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values
     */
    @JvmName("bcnbescdofvftnef")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): DashboardParametersDateTimeParameterArgs =
        DashboardParametersDateTimeParameterArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            values = values ?: throw PulumiNullFieldException("values"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardParametersDateTimeParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardParametersDateTimeParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Display name for the dashboard.
 * @property values
 */
public data class DashboardParametersDateTimeParameterArgs(
    public val name: Output<String>,
    public val values: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardParametersDateTimeParameterArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardParametersDateTimeParameterArgs =
        com.pulumi.aws.quicksight.inputs.DashboardParametersDateTimeParameterArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DashboardParametersDateTimeParameterArgs].
 */
@PulumiTagMarker
public class DashboardParametersDateTimeParameterArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var values: Output<List<String>>? = null

    /**
     * @param value Display name for the dashboard.
     */
    @JvmName("getyjjnafrwxkckt")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("gonihdsovmudbvxe")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("gscuxtleijecwwvb")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("lipjhaqtfdoauxig")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Display name for the dashboard.
     */
    @JvmName("dsvvgdsjdxefxywd")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("pqxscqpsiccbcwtu")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values
     */
    @JvmName("hksiwujuwkoxysmq")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): DashboardParametersDateTimeParameterArgs =
        DashboardParametersDateTimeParameterArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            values = values ?: throw PulumiNullFieldException("values"),
        )
}
